#!/bin/bash

#	name:		relaxCoordinator.sh
#	author:		Kevin Molloy
#	date:		January 2014
#	purpose:	Coordinate running multiple Rosetta relax
#			jobs across multiple nodes on Hydra.
#
#	args:		Directory to scan for input
#			Max number of jobs to run at the same time

#	usage:		-- place the PDB file you want to start with in the
#			input directory.
#			-- place a file in the input directory with the same
#			name as the PDB plus a ".start" extension
#
#			-- when processing has completed, a file 
#			with the original name, minus the PDB extension,
#			plus a ".done" extension.
#
#			-- the processed PDB will be with the 
#			full original name plus a ".output" extension

#	notes:		You will need to modify SOFTWARE_DIR to
#			the location where you put the scripts.
#			
#			To change the nodes on which jobs are dispatched,
#			change the findNode.py script.
#
#			Because SHELL scripts kick off new processes for
#			while loops, variable changes within these loops
#			are not visable to the outside.  This is why
#			we write the currentNodeNumber to a file.

if [ $# -ne 2 ]
then
  echo usage:relaxCoordinator.sh INPUT_DIR MAX_JOBS
  exit 99
fi

INPUT_DIR=$( cd ${1} && pwd)
MAX_JOBS=${2}

SOFTWARE_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

## read in global variables
. ${SOFTWARE_DIR}/relaxCoordinatorVars.sh

myNode=`hostname`

cd ${INPUT_DIR}

while :
do
  concurrent=`ls *.working 2> /dev/null | wc -l`
  echo
  echo Currently processing ${concurrent} jobs at time `date`
  echo ------------------------------------

  ls -1 *.start 2> /dev/null | while read FILENAME;
  do
    BN=`basename ${FILENAME} .pdb.start`
    concurrent=`ls *.working 2> /dev/null | wc -l`

    if [ ! -f ${BN}.working -a ${concurrent} -lt ${MAX_JOBS} ]
    then
      echo processing ${FILENAME} sending to node ${nodeName}

      rm ${FILENAME}   ## remove start file
      touch ${BN}.working

      nice ${SOFTWARE_DIR}/runRelax.sh \
           ${INPUT_DIR}/${BN}.pdb \
           ${INPUT_DIR}/${BN}.pdb.output  \
           ${INPUT_DIR}/${BN} \
           ${SOFTWARE_DIR} > ${BN}.log 2>&1

      echo Dispatch complete
    fi
  done

  echo sleeping...
  sleep 2
done
